@@ -548,6 +548,9 @@ class SimulationBuilder(LEMSBase):
         # Process kinetic schemes
         ks_code = []
         for ks in regime.kinetic_schemes:
+            
+            raise NotImplementedError("KineticScheme element is not stable in PyLEMS yet, see https://github.com/LEMS/pylems/issues/15")
+        
             try:
                 ###nodes = {node.id:node for node in runnable.__dict__[ks.nodes]}
                 nodes = {}
@@ -651,7 +654,9 @@ class SimulationBuilder(LEMSBase):
             return '<='
         elif op == '.eq.':
             return '=='
-        elif op == '.ne.':
+        elif op == '.neq.':   
+            return '!='
+        elif op == '.ne.':   # .neq. is preferred!
             return '!='
         elif op == '^':
             return '**'
